@@ -127,12 +127,12 @@ class WorkerServer(BaseServer):
             queue=self.amqp_queue,
             durable=False,
             exclusive=False,
-            auto_delete=True)
+            auto_delete=False)
         yield self.chan.queue_bind(
             queue=self.amqp_queue,
             exchange=self.amqp_exchange)
         yield self.chan.basic_consume(queue=self.amqp_queue,
-            no_ack=False,
+            no_ack=True,
             consumer_tag="awspider_consumer")
         self.queue = yield self.conn.queue("awspider_consumer")
         yield BaseServer.start(self)
